package com.chelvc.framework.base.context;

import java.io.Serializable;
import java.util.Collections;
import java.util.Set;

import com.chelvc.framework.common.model.Platform;
import com.chelvc.framework.common.model.Terminal;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.NonNull;
import lombok.ToString;

/**
 * 会话信息
 *
 * @author Woody
 * @date 2024/1/30
 */
@Getter
@Builder
@ToString
@NoArgsConstructor
@AllArgsConstructor
public class Session implements Serializable {
    /**
     * 会话信息命名
     */
    public static final String NAMING = "session";

    /**
     * 主体标识
     */
    private Long id;

    /**
     * 使用类别
     */
    private Using using;

    /**
     * 请求地址
     */
    private String host;

    /**
     * 应用范围
     */
    private String scope;

    /**
     * 手机号码
     */
    private String mobile;

    /**
     * 设备标识
     */
    private String device;

    /**
     * 渠道来源
     */
    private String channel;

    /**
     * 应用平台
     */
    private Platform platform;

    /**
     * 客户终端
     */
    private Terminal terminal;

    /**
     * 终端版本
     */
    private String version;

    /**
     * 权限标识集合
     */
    private Set<String> authorities;

    /**
     * 请求时间戳
     */
    private Long timestamp;

    /**
     * 初始化会话主体信息
     *
     * @param id          主体标识
     * @param using       使用类别
     * @param scope       应用范围
     * @param mobile      手机号码
     * @param authorities 权限标识集合
     */
    void initializePrincipal(@NonNull Long id, @NonNull Using using, @NonNull String scope, String mobile,
                             @NonNull Set<String> authorities) {
        this.id = id;
        this.using = using;
        this.scope = scope;
        this.mobile = mobile;
        this.authorities = Collections.unmodifiableSet(authorities);
    }
}
